import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import pystan
import seaborn as sb


df = pd.read_csv('data.csv')
data = df.values
X = data.T[1]
Y = data.T[2]
for x, y in zip(X, Y):
    print(x, y)

Z = X - np.mean(X)
plt.plot(Z, Y, 'o')
plt.xlabel('Z', fontsize = 14)
plt.ylabel('Y', fontsize = 14)
plt.show()

sm = pystan.StanModel(file = 'simple_regression.stan')
print('Compiling end.')

Data = {'N':len(Z), 'X':Z, 'Y':Y}
fit = sm.sampling(data = Data, n_jobs = 1)
print(fit)

a_hat = np.median(fit['a'])
b_hat = np.median(fit['b'])
sb.kdeplot(fit['a'])
plt.title('a: median = {0:.2f}'.format(a_hat))
plt.savefig('FigZ_a.png')
plt.show()

sb.kdeplot(fit['b'])
plt.title('b: median = {0:.2f}'.format(b_hat))
plt.savefig('FigZ_b.png')
plt.show()

plt.plot(fit['b'], fit['a'], 'o')
plt.xlabel('b', fontsize = 16)
plt.ylabel('a', fontsize = 16)
plt.savefig('FigZ_ab.png')
plt.show()

plt.plot(Z, Y, 'o')
plt.plot([min(Z), max(Z)], [a_hat + b_hat * min(Z), a_hat + b_hat * max(Z)],
        label = 'Regression Line')
plt.plot(0, a_hat, 's', c = 'r', label = (r'(0, $\hat{a}$)')  + ('\n$\hata$={0:.2f}'.format(a_hat)))
plt.xlabel(r'Z = X - $\bar{X}$', fontsize = 16)
plt.ylabel('Y', fontsize = 16)
plt.legend(fontsize = 14)
plt.savefig('FigZ_regress.png')
plt.show()
