import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import pystan
import seaborn as sb


df = pd.read_csv('data.csv')
#print(df)
data = df.values
#print('data =\n', data)
X = data.T[1]
Y = data.T[2]
for x, y in zip(X, Y):
    print(x, y)
    
sm = pystan.StanModel(file = 'simple_regression.stan')
print('Compiling end.')

Data = {'N':len(X), 'X':X, 'Y':Y}
fit = sm.sampling(data = Data, n_jobs = 1)
print(fit)

a_hat = np.median(fit['a'])
b_hat = np.median(fit['b'])
sb.kdeplot(fit['a'])
plt.title('a: median = {0:.2f}'.format(a_hat), fontsize = 18)
plt.savefig('Fig_a.png')
plt.show()

sb.kdeplot(fit['b'])
plt.title('b: median = {0:.2f}'.format(b_hat), fontsize = 18)
plt.savefig('Fig_b.png')
plt.show()

plt.plot(fit['b'], fit['a'], 'o')
plt.xlabel('b', fontsize = 20)
plt.ylabel('a', fontsize = 20)
plt.savefig('Fig_scatter_ab.png')
plt.show()

plt.plot(X, Y, 'o', label = 'Data')
plt.plot([min(X), max(X)], [a_hat + b_hat * min(X), a_hat + b_hat * max(X)],
        label = 'Regression Line')
plt.xlabel('X', fontsize = 16)
plt.ylabel('Y', fontsize = 16)
plt.legend(fontsize = 14)
plt.savefig('FigSRegress.png')
plt.show()
